Description Usage Arguments Details Value
Basic filter functions return functions with bindings for A. The function evaluates to TRUE if some operation on the input results in a value greater/smaller than A.
1 2 3 4 5 6 7 |
A |
The value that should / should not be exceeded. |
na.rm |
Whether NAs should be removed. |
The basic filter functions in detail:
EpOverA evaluates to TRUE if the aggregate of the arguments elements are larger than A.
FanoOverA evaluates to TRUE if the Fano factor of the argument is larger than A.
MeanBelowA evaluates to TRUE if the mean of the arguments elements are smaller than A.
MeanOverA evaluates to TRUE if the mean of the arguments elements are greater than A.
A function with bindings for A.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.