Description Usage Arguments Value
Performs HDBSCAN clustering on a SingleCellExperiment object. The algorithm is explained in detail in McInnes et. al. and needs the python package hdbscan installed.
1 2 |
object |
A SingleCellExperiment object. |
use_dimred |
A string or integer scalar indicating the reduced dimension result in |
min_samples |
Measure of how conservative the clustering should to be. The larger the value of |
min_cluster_size |
The smallest size grouping that is considered a cluster. |
outlier |
Determines how outliers are encoded in the resulting clustering. |
seed |
A numeric seed to initialize the random number generator. |
A factor with the assigned cluster.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.